#------------------------------------------------------------------
#
# Sept. 2007 - Christine Yan (cyan@cisco.com)
#
# Copyright (c) 2007-2009 by cisco Systems, Inc.
# All rights reserved.
#
# Version-date: v1.0-09/09/2007
#
# Name: diag_lib.tcl
#
# Desc: lib procedures to be shared by triggering scripts
#
#------------------------------------------------------------------

###############################################################################
# 
#   Description: set_eem_env
#                set eem environment variable
#
#   IN: env_name: eem environment variable name 
#       env_value: eem environment variable value
#
###############################################################################

proc set_eem_env { env_name env_value } {
    if {[catch {ios_config \
        "event manager environment $env_name $env_value"} err]} {
        set err [string trim $err]
        puts "err is \"$err\" --- Failed to set env $env_name"
    }
}

###############################################################################
# 
#   Description: set_eem_dir
#                set eem user directory name
#
#   IN: type: user policy or user library
#       dir_name: the location dir for user policy or user library
#
###############################################################################

proc set_eem_dir { type dir_name } {
    if {[catch {ios_config \
        "event manager directory user $type $dir_name"} err]} {
        set err [string trim $err]
        puts "err is \"$err\" --- Failed to config EEM user $type directory"
    }
}

###############################################################################
# 
#   Description: unset_eem_dir
#                unset eem user directory name
#
#   IN: type: user policy or user library
#
###############################################################################

proc unset_eem_dir { type } {
    if {[catch {ios_config \
        "no event manager directory user $type"} err]} {
        set err [string trim $err]
        puts "err is \"$err\" --- Failed to remove EEM user $type directory"
    }
}

###############################################################################
# 
#   Description: unreg_eem_policy
#                unregister eem policy
#
#   IN: eem policy name
#   OUT: return 1 if it is successful.  Otherwise, return 0
#
###############################################################################

proc unreg_eem_policy { policy_name } {
    if {[catch {ios_config \
        "no event manager policy $policy_name type user"} err]} {
        set err [string trim $err]
        puts "err is \"$err\" --- Failed to remove policy $policy_name"
        return 0
    } else {
        puts "$policy_name is unregistered successfully"
        return 1
    }
}

###############################################################################
# 
#   Description: reg_eem_policy
#                register eem policy
#
#   IN: eem policy name
#   OUT: return 1 if it is successful.  Otherwise, return 0
#
###############################################################################

proc reg_eem_policy { policy_name } {
    set code 0
    if {[catch {ios_config \
        "event manager policy $policy_name type user"} err]} {
        set err [string trim $err]
        puts "err is \"$err\" --- Failed to configure eem policy $policy_name"
        set code 0
    } else {
        if { $err == "" } {
	    puts "Policy $policy_name successfully registered"
            set code 1
        } else {
	    set err [string trim $err]
	    puts "err is \"$err\" --- Failed to register policy $policy_name"
            set code 0
        }
    }
    return $code
}

###############################################################################
# 
#   Description: delete_temp
#                delete a temp file
#
#   IN: temp file name
#
###############################################################################
proc delete_temp { temp_file } {
    if {[catch {exec del /force $temp_file} err]} {
        puts "err \"$err\" --- Temp file $temp_file Failed to be deleted"
    }
}

###############################################################################
# 
#   Description: display_registered_policy
#                display all registered policies
#
#
###############################################################################
proc display_registered_policy { } {

    set has_policy 0

    if {[catch {exec "show event man po reg | i script" } result ] == 0 } {
        foreach line [split $result "\n"] {
            set policy_num [llength $line]
            set policy_name [lindex $line [expr {$policy_num} - 1] ]
            if { $policy_name != ""} {
                puts "$policy_name is registered"
                set has_policy 1
            }
        }
    }

    if { $has_policy == 0 } {
        puts "No policy is registered"
    }
}



#Cisco Tcl Signature V1.0
#3082077506092a864886f70d010702a082076630820762020101310b3009
#06052b0e03021a0500300b06092a864886f70d010701a08204bb308204b7
#3082039fa003020102020900d48b1bbfb069e9b9300d06092a864886f70d
#0101050500308198310b3009060355040613024341311230100603550408
#130963616c69666f6e69613111300f060355040713086d69706c69746173
#311b3019060355040a1312636973636f2073797374656d7320696e632e31
#0e300c060355040b13054e53535447311630140603550403130d43687269
#7374696e652059616e311d301b06092a864886f70d010901160e6379616e
#40636973636f2e636f6d301e170d3037313231383138333232375a170d31
#30313231373138333232375a308198310b30090603550406130243413112
#30100603550408130963616c69666f6e69613111300f060355040713086d
#69706c69746173311b3019060355040a1312636973636f2073797374656d
#7320696e632e310e300c060355040b13054e535354473116301406035504
#03130d436872697374696e652059616e311d301b06092a864886f70d0109
#01160e6379616e40636973636f2e636f6d30820122300d06092a864886f7
#0d01010105000382010f003082010a02820101009c22f1d01af397756ab6
#cfce92a9e761b73fbf1efd070aa4e90448e6077e2c127ff47a5951de7790
#55da014ff152576a08d7199b8ad5757eb8c9a7c1a493715df2176e9f56f0
#74735d43420cf1ed17fe0aa3494724808aefcf274572c7750be071a94560
#9c045c48a5454f9e7933bf93d967bcf582918b1bbd48f47dd978c7ea9c88
#23eb01482a40ef770f823ea2e63eaf7cab5367bd51b54979925464e27b22
#82fc5bfe94f6f41f2f91e56444ae371a050107fe79fd5db3f228bbbd5fcb
#653a87a3c1268d74500ba1489382290804d9d7937d3269b1c55eae51f9f7
#62eadbd4226ba6d4008414b353181ee6cfbe24204e4a82436b117c255014
#77ec74c3ac4d0203010001a38201003081fd301d0603551d0e041604149c
#0e12d3a222891fc1300b780f38b54e07e228073081cd0603551d230481c5
#3081c280149c0e12d3a222891fc1300b780f38b54e07e22807a1819ea481
#9b308198310b300906035504061302434131123010060355040813096361
#6c69666f6e69613111300f060355040713086d69706c69746173311b3019
#060355040a1312636973636f2073797374656d7320696e632e310e300c06
#0355040b13054e53535447311630140603550403130d436872697374696e
#652059616e311d301b06092a864886f70d010901160e6379616e40636973
#636f2e636f6d820900d48b1bbfb069e9b9300c0603551d13040530030101
#ff300d06092a864886f70d010105050003820101003e6d657e30c21acb30
#d7e91aef99cd6f83a8644d7ae437fb4a0cd1a8c6a0f1cb2194be80868b75
#1d20ee8dc72a1f80de697928820ec3f806cec67df136d6f8b6ff0ba7ef6f
#e4c228b37e7407becff9903198ebe2258d3774f198de8d0366cb10496408
#57dff62f247dfcae9813fde4167c1f959b291490cfb8e0b8db3395ce019f
#07c94aa4a86d1a0dae2b6cc6d139db740841dc65add58512ea59336dbc8c
#9abc14d500e42c8ea5031c201eec027d14e9878974629d2fdbe0d0cfffab
#8ab73f148bdec788de59550443ccf12cb3e74518274c3d7d2892eeb90f23
#0d5e853b85542c05b12198c097c2fb4023b370f0629645e11552f5429fb8
#aacef60a9344b5318202823082027e0201013081a6308198310b30090603
#55040613024341311230100603550408130963616c69666f6e6961311130
#0f060355040713086d69706c69746173311b3019060355040a1312636973
#636f2073797374656d7320696e632e310e300c060355040b13054e535354
#47311630140603550403130d436872697374696e652059616e311d301b06
#092a864886f70d010901160e6379616e40636973636f2e636f6d020900d4
#8b1bbfb069e9b9300906052b0e03021a0500a081b1301806092a864886f7
#0d010903310b06092a864886f70d010701301c06092a864886f70d010905
#310f170d3039303431363137343935305a302306092a864886f70d010904
#311604149ae57f2ef3ce29aa836594e1cfeba0231d70f0a7305206092a86
#4886f70d01090f31453043300a06082a864886f70d0307300e06082a8648
#86f70d030202020080300d06082a864886f70d0302020140300706052b0e
#030207300d06082a864886f70d0302020128300d06092a864886f70d0101
#0105000482010074a9ffce3a5fddf8e8f3c15f1015a9986e2ba4b9b389ce
#9afd392c4c7879448238c5975ff8f18658958a5ef3bee551df10e640a4ef
#3385c2b486195b66d5f734fecc0448247a1ab36b900ae38e4075328a0582
#c7f150101af562a6781f783c34c58ee6ee115f6a136712550e450a30c2b8
#8565316d95023072a494a196a46636c536722faa703e6825fb9a607af68f
#a7aae4e938643819eb0ad27e19cea8837d792e931a3c53373577843cf98a
#b358bee556db0eec64d34ef737a67eed0b6e81ee5a5272fc8af9d6dc4b99
#f7a1d3006082151fef80dd537caeac35ac6bf64152a2cb5cec0beb92baa7
#fd1aa0cb1082544a11e55ceae10f90daf7ca2547fd1619
