::cisco::eem::event_register_none maxrun 600

#------------------------------------------------------------------------------
# EEM policy to troubleshoot and collect information regarding the service
# associated with a given CFM Maintenance Association (MA) name, domain name or
# Maintenance Association End Point <MA, domain, MEP> combination
# The policy will be manually run on demand ie has none event detector.
#
# March 2009 - Vimaladevi Rajakanthan (vrajakan@cisco.com)
#
# Copyright (c) 2009 by cisco Systems, Inc.
# All rights reserved.
#
# Version-date: v1.0 03/05/2009
# Title: Reports all the information related to the MA, domain and/or MEP id
#        given by the user
#
# Name: cfm_ondemand.tcl
# Desc: This script will collect information related to the remote mep/meps
#       for the MA, domain and/or MEP id provided by the user on demand. 
#
#       The structure and requirment of the file is defined below., 
#
#       For the purpose of test automation an environment variable _automation
#       is required. This environment variable is checked if defined
#       previously and if not is defined.
#
# Environment Variables for this script are:
# _svcdiag_cfmOndemandNotif: notification - email/syslog/snmp/all
# _svcdiag_cfmOndemandConfig: configuration history - true/false
# _svcdiag_cfmOndemandEvent: event history - true/false
# _svcdiag_cfmOndemandCommand: command history - true/false
# _svcdiag_cfmOndemandPrepend: prepend trigger message - true or false
# _svcdiag_cfmOndemandMAname: MA name
# _svcdiag_cfmOndemandDomain: domain name
# _svcdiag_cfmOndemandMpid: mpid - which is optional
# _automation: Test automation - true/false
#
#------------------------------------------------------------------------------

namespace import ::cisco::eem::*
namespace import ::cisco::lib::*

### Initialize global variables ###
global trace
set policy 1
set cmd ""
set vlan ""
set level ""
set script "cfm_ondemand.tcl"

### check for environment variable that sets the debug flag ###
if {![info exists _debug_cfm_ondemand]} {
    set _debug_cfm_ondemand 0  
}
set trace $_debug_cfm_ondemand 

### Check generic policy environment variables
if {[check_policy_env "_svcdiag_cfmOndemand" cmd automation] != 0} {
    exit
}

set cmd2 ""
### check for existence of policy specific environment variables ###

### check for  null value or existence of domain name ###
if {![info exists _svcdiag_cfmOndemandDomain]} {
    set err "Domain environment variable \"_svcdiag_cfmOndemandDomain\"\
             is not set"
    exit_policy_script_with_errors $script $err
    exit
} elseif {$_svcdiag_cfmOndemandDomain == ""} {
    set err "Domain environment variable \"_svcdiag_cfmOndemandDomain\"\
             has no value" 
    exit_policy_script_with_errors $script $err
    exit
} elseif {[validate_domain $_svcdiag_cfmOndemandDomain $cmd2 $policy] == 0} {
    exit_policy_script_with_errors $script 
    exit
}

### check for existence or null value of MA name ###
if {![info exists _svcdiag_cfmOndemandMAname]} {
    set err "MA name environment variable \"_svcdiag_cfmOndemandMAname\"\
             is not set"
    exit_policy_script_with_errors $script $err
    exit
} elseif {$_svcdiag_cfmOndemandMAname == ""} {
    set err "MA name environment variable \"_svcdiag_cfmOndemandMAname\" has\
             no value" 
    exit_policy_script_with_errors $script $err
    exit
} elseif {[validate_ma_name $_svcdiag_cfmOndemandDomain\
                            $_svcdiag_cfmOndemandMAname $policy] == 0} {
    exit_policy_script_with_errors $script 
    exit
}

### validate mpid ###
if {![info exists _svcdiag_cfmOndemandMpid]} {
    set err "Mpid environment variable: _svcdiag_cfmOndemandMpid is\
             not set"
    exit_policy_script_with_errors $script $err
    exit
} elseif {$_svcdiag_cfmOndemandMpid == ""} {
    set mpid "NULL"
}

### Initialize Command History, vlan and domain level variables ###
set level ""
set vlan ""
set meplist {}

### Policy execution starts from here ###
debug $trace "Ondemand script starts..."

### Assign the environment varaibles ###
set ma $_svcdiag_cfmOndemandMAname
set domain $_svcdiag_cfmOndemandDomain
set mpid $_svcdiag_cfmOndemandMpid
debug $trace  "MA name: $ma, Domain name: $domain, Mpid: $mpid" 2

### Get domain details from domain db ###
if {[get_domain_details $domain $ma $policy cmd vlan level] == 0} {
    exit_policy_script_with_errors $script
    exit
}

set scenario "demand" 
### If MEP id not given ###
if { [string match $mpid "NULL"] == 1 } {
    if { [prepare_ondemand_report cmd summary detail $domain $ma $vlan $level\
                                 $scenario] == 0 } {
        exit_policy_script_with_errors $script 
        exit
    }     
} else {
### If MEP id is given ###
    if {[prepare_report cmd summary detail $mpid $domain $vlan $level $ma\
                        $scenario] == 0} {
        exit_policy_script_with_errors $script 
        exit
    }
}

debug $trace "Command history: $cmd" 2
debug $trace "SUMMARY: $summary" 2
debug $trace "DETAILS: $detail" 2

set len [string length $summary]
debug $trace "Length of summary is :$len"

set trigger_message "Ondemand script run manually"
### Send out the summary and detailed message via notification
send_notification $summary $detail $_svcdiag_cfmOndemandNotif\
    $_svcdiag_cfmOndemandConfig $_svcdiag_cfmOndemandEvent\
    $_svcdiag_cfmOndemandCommand $cmd $_svcdiag_cfmOndemandPrepend\
    $trigger_message $automation

debug $trace "On-demand script is done." 
